'use strict';

function __$styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

__$styleInject("._customMenu_qjy5r_1 {\n  display: none;\n  z-index: 1000;\n  position: absolute;\n  overflow: hidden;\n  border: 1px solid #CCC;\n  white-space: nowrap;\n  font-family: sans-serif;\n  background: #FFF;\n  color: #333;\n  list-style: none;\n  padding:0;\n  margin: 0;\n}\n\n._customMenu_qjy5r_1 li {\n  padding: 8px 12px;\n  cursor: pointer;\n}\n\n._customMenu_qjy5r_1 li:hover {\n  background-color: #DEF;\n}\n", {});
var styles = {"customMenu":"_customMenu_qjy5r_1"};

/**
 * @class AmchartsReact
 *
 */
var AmchartsReact = /** @class */ (function (_super) {
    __extends(AmchartsReact, _super);
    function AmchartsReact() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            show: false,
            top: 0,
            left: 0,
            chart: {},
            axises: [],
            range: {
                start: 0,
                end: 0
            }
        };
        /**
         * Create a axis range according to the range in the given axis
         *
         * @param axis - x axis to know the position
         * @param {Range} range - range of the axis range
         * @param xAxis - On this axis the axis range will be created
         */
        _this.createAxisRange = function (axis, range, xAxis) {
            var axisRange = xAxis.axisRanges.create();
            axisRange.date = axis.positionToDate(range.start);
            axisRange.endDate = axis.positionToDate(range.end);
            axisRange.axisFill.fill = _this.props.color;
            axisRange.axisFill.fillOpacity = 0.4;
            axisRange.label.disabled = true;
            xAxis.validateData();
        };
        /**
         * Change the default cursor behavior to "selectX" from "zoomX"
         * And create a axis range on the range after "selectended"
         *
         * @param chart
         */
        _this.cursorBehaviorChangeHandler = function (chart) {
            var xAxis = _this.props.xAxis;
            chart.cursor.behavior = "selectX";
            chart.cursor.events.on("selectended", function (ev) {
                var range = ev.target.xRange;
                var xAxes = ev.target.chart.xAxes;
                var axises = [];
                xAxes.values.map(function (value) {
                    axises.push(value);
                });
                _this.setState(function () { return ({ axises: axises, range: range }); });
                _this.createAxisRange(axises[0], range, xAxis);
                var _a = ev.target.point, x = _a.x, y = _a.y;
                _this.setState(function () { return ({ show: true, top: y + 102, left: x + 270 }); });
            });
            chart.events.on("hit", function () {
                var length = xAxis.axisRanges.length;
                _this.setState(function () { return ({ show: false }); });
                if (length > 1) {
                    xAxis.axisRanges.removeIndex(length - 1);
                }
            });
        };
        /**
         * handles the zoom after the zoom context menu is clicked by user
         *
         */
        _this.handleZoom = function () {
            var _a = _this.state, axises = _a.axises, range = _a.range;
            var xAxis = _this.props.xAxis;
            var length = xAxis.axisRanges.length;
            if (length > 1) {
                xAxis.axisRanges.removeIndex(length - 1);
            }
            axises.map(function (axis) {
                axis.zoomToDates(axis.positionToDate(range.start), axis.positionToDate(range.end));
            });
            _this.setState(function () { return ({ show: false }); });
        };
        return _this;
    }
    /**
     * After component will be mounted this method will be invoked
     *
     */
    AmchartsReact.prototype.componentDidMount = function () {
        this.cursorBehaviorChangeHandler(this.props.chart);
    };
    /**
     * Renders this React component
     *
     * @returns {any}
     */
    AmchartsReact.prototype.render = function () {
        var _a = this.state, show = _a.show, top = _a.top, left = _a.left;
        var style = show ? {
            display: 'block',
            top: top,
            left: left
        } : {
            display: 'none'
        };
        return (React.createElement("ul", { className: styles.customMenu, style: style },
            React.createElement("li", { onClick: this.handleZoom }, "Zoom"),
            React.createElement("li", null, " Pattern search")));
    };
    return AmchartsReact;
}(React.Component));

exports.AmchartsReact = AmchartsReact;
//# sourceMappingURL=index.js.map
